@@ -13,20 +13,31 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Sequence
+from typing import Dict, List, Mapping, Sequence
 
 from .literals import (
     ConnectionStateType,
+    ConnectionStatusType,
+    ConnectionTypeType,
     CustomerGatewayAssociationStateType,
     DeviceStateType,
     GlobalNetworkStateType,
     LinkAssociationStateType,
     LinkStateType,
+    RouteAnalysisCompletionReasonCodeType,
+    RouteAnalysisCompletionResultCodeType,
+    RouteAnalysisStatusType,
+    RouteStateType,
+    RouteTypeType,
     SiteStateType,
     TransitGatewayConnectPeerAssociationStateType,
     TransitGatewayRegistrationStateType,
 )
 
+if sys.version_info >= (3, 9):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
 if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
@@ -42,6 +53,7 @@ __all__ = (
     "AssociateTransitGatewayConnectPeerRequestRequestTypeDef",
     "AssociateTransitGatewayConnectPeerResponseTypeDef",
     "BandwidthTypeDef",
+    "ConnectionHealthTypeDef",
     "ConnectionTypeDef",
     "CreateConnectionRequestRequestTypeDef",
     "CreateConnectionResponseTypeDef",
@@ -85,6 +97,18 @@ __all__ = (
     "GetLinkAssociationsResponseTypeDef",
     "GetLinksRequestRequestTypeDef",
     "GetLinksResponseTypeDef",
+    "GetNetworkResourceCountsRequestRequestTypeDef",
+    "GetNetworkResourceCountsResponseTypeDef",
+    "GetNetworkResourceRelationshipsRequestRequestTypeDef",
+    "GetNetworkResourceRelationshipsResponseTypeDef",
+    "GetNetworkResourcesRequestRequestTypeDef",
+    "GetNetworkResourcesResponseTypeDef",
+    "GetNetworkRoutesRequestRequestTypeDef",
+    "GetNetworkRoutesResponseTypeDef",
+    "GetNetworkTelemetryRequestRequestTypeDef",
+    "GetNetworkTelemetryResponseTypeDef",
+    "GetRouteAnalysisRequestRequestTypeDef",
+    "GetRouteAnalysisResponseTypeDef",
     "GetSitesRequestRequestTypeDef",
     "GetSitesResponseTypeDef",
     "GetTransitGatewayConnectPeerAssociationsRequestRequestTypeDef",
@@ -97,11 +121,27 @@ __all__ = (
     "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "LocationTypeDef",
+    "NetworkResourceCountTypeDef",
+    "NetworkResourceSummaryTypeDef",
+    "NetworkResourceTypeDef",
+    "NetworkRouteDestinationTypeDef",
+    "NetworkRouteTypeDef",
+    "NetworkTelemetryTypeDef",
     "PaginatorConfigTypeDef",
+    "PathComponentTypeDef",
     "RegisterTransitGatewayRequestRequestTypeDef",
     "RegisterTransitGatewayResponseTypeDef",
+    "RelationshipTypeDef",
     "ResponseMetadataTypeDef",
+    "RouteAnalysisCompletionTypeDef",
+    "RouteAnalysisEndpointOptionsSpecificationTypeDef",
+    "RouteAnalysisEndpointOptionsTypeDef",
+    "RouteAnalysisPathTypeDef",
+    "RouteAnalysisTypeDef",
+    "RouteTableIdentifierTypeDef",
     "SiteTypeDef",
+    "StartRouteAnalysisRequestRequestTypeDef",
+    "StartRouteAnalysisResponseTypeDef",
     "TagResourceRequestRequestTypeDef",
     "TagTypeDef",
     "TransitGatewayConnectPeerAssociationTypeDef",
@@ -116,6 +156,8 @@ __all__ = (
     "UpdateGlobalNetworkResponseTypeDef",
     "UpdateLinkRequestRequestTypeDef",
     "UpdateLinkResponseTypeDef",
+    "UpdateNetworkResourceMetadataRequestRequestTypeDef",
+    "UpdateNetworkResourceMetadataResponseTypeDef",
     "UpdateSiteRequestRequestTypeDef",
     "UpdateSiteResponseTypeDef",
 )
@@ -219,6 +261,16 @@ BandwidthTypeDef = TypedDict(
     total=False,
 )
 
+ConnectionHealthTypeDef = TypedDict(
+    "ConnectionHealthTypeDef",
+    {
+        "Type": ConnectionTypeType,
+        "Status": ConnectionStatusType,
+        "Timestamp": datetime,
+    },
+    total=False,
+)
+
 ConnectionTypeDef = TypedDict(
     "ConnectionTypeDef",
     {
@@ -754,6 +806,206 @@ GetLinksResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredGetNetworkResourceCountsRequestRequestTypeDef = TypedDict(
+    "_RequiredGetNetworkResourceCountsRequestRequestTypeDef",
+    {
+        "GlobalNetworkId": str,
+    },
+)
+_OptionalGetNetworkResourceCountsRequestRequestTypeDef = TypedDict(
+    "_OptionalGetNetworkResourceCountsRequestRequestTypeDef",
+    {
+        "ResourceType": str,
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class GetNetworkResourceCountsRequestRequestTypeDef(
+    _RequiredGetNetworkResourceCountsRequestRequestTypeDef,
+    _OptionalGetNetworkResourceCountsRequestRequestTypeDef,
+):
+    pass
+
+
+GetNetworkResourceCountsResponseTypeDef = TypedDict(
+    "GetNetworkResourceCountsResponseTypeDef",
+    {
+        "NetworkResourceCounts": List["NetworkResourceCountTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredGetNetworkResourceRelationshipsRequestRequestTypeDef = TypedDict(
+    "_RequiredGetNetworkResourceRelationshipsRequestRequestTypeDef",
+    {
+        "GlobalNetworkId": str,
+    },
+)
+_OptionalGetNetworkResourceRelationshipsRequestRequestTypeDef = TypedDict(
+    "_OptionalGetNetworkResourceRelationshipsRequestRequestTypeDef",
+    {
+        "RegisteredGatewayArn": str,
+        "AwsRegion": str,
+        "AccountId": str,
+        "ResourceType": str,
+        "ResourceArn": str,
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class GetNetworkResourceRelationshipsRequestRequestTypeDef(
+    _RequiredGetNetworkResourceRelationshipsRequestRequestTypeDef,
+    _OptionalGetNetworkResourceRelationshipsRequestRequestTypeDef,
+):
+    pass
+
+
+GetNetworkResourceRelationshipsResponseTypeDef = TypedDict(
+    "GetNetworkResourceRelationshipsResponseTypeDef",
+    {
+        "Relationships": List["RelationshipTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredGetNetworkResourcesRequestRequestTypeDef = TypedDict(
+    "_RequiredGetNetworkResourcesRequestRequestTypeDef",
+    {
+        "GlobalNetworkId": str,
+    },
+)
+_OptionalGetNetworkResourcesRequestRequestTypeDef = TypedDict(
+    "_OptionalGetNetworkResourcesRequestRequestTypeDef",
+    {
+        "RegisteredGatewayArn": str,
+        "AwsRegion": str,
+        "AccountId": str,
+        "ResourceType": str,
+        "ResourceArn": str,
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class GetNetworkResourcesRequestRequestTypeDef(
+    _RequiredGetNetworkResourcesRequestRequestTypeDef,
+    _OptionalGetNetworkResourcesRequestRequestTypeDef,
+):
+    pass
+
+
+GetNetworkResourcesResponseTypeDef = TypedDict(
+    "GetNetworkResourcesResponseTypeDef",
+    {
+        "NetworkResources": List["NetworkResourceTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredGetNetworkRoutesRequestRequestTypeDef = TypedDict(
+    "_RequiredGetNetworkRoutesRequestRequestTypeDef",
+    {
+        "GlobalNetworkId": str,
+        "RouteTableIdentifier": "RouteTableIdentifierTypeDef",
+    },
+)
+_OptionalGetNetworkRoutesRequestRequestTypeDef = TypedDict(
+    "_OptionalGetNetworkRoutesRequestRequestTypeDef",
+    {
+        "ExactCidrMatches": Sequence[str],
+        "LongestPrefixMatches": Sequence[str],
+        "SubnetOfMatches": Sequence[str],
+        "SupernetOfMatches": Sequence[str],
+        "PrefixListIds": Sequence[str],
+        "States": Sequence[RouteStateType],
+        "Types": Sequence[RouteTypeType],
+        "DestinationFilters": Mapping[str, Sequence[str]],
+    },
+    total=False,
+)
+
+
+class GetNetworkRoutesRequestRequestTypeDef(
+    _RequiredGetNetworkRoutesRequestRequestTypeDef, _OptionalGetNetworkRoutesRequestRequestTypeDef
+):
+    pass
+
+
+GetNetworkRoutesResponseTypeDef = TypedDict(
+    "GetNetworkRoutesResponseTypeDef",
+    {
+        "RouteTableArn": str,
+        "RouteTableType": Literal["TRANSIT_GATEWAY_ROUTE_TABLE"],
+        "RouteTableTimestamp": datetime,
+        "NetworkRoutes": List["NetworkRouteTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredGetNetworkTelemetryRequestRequestTypeDef = TypedDict(
+    "_RequiredGetNetworkTelemetryRequestRequestTypeDef",
+    {
+        "GlobalNetworkId": str,
+    },
+)
+_OptionalGetNetworkTelemetryRequestRequestTypeDef = TypedDict(
+    "_OptionalGetNetworkTelemetryRequestRequestTypeDef",
+    {
+        "RegisteredGatewayArn": str,
+        "AwsRegion": str,
+        "AccountId": str,
+        "ResourceType": str,
+        "ResourceArn": str,
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class GetNetworkTelemetryRequestRequestTypeDef(
+    _RequiredGetNetworkTelemetryRequestRequestTypeDef,
+    _OptionalGetNetworkTelemetryRequestRequestTypeDef,
+):
+    pass
+
+
+GetNetworkTelemetryResponseTypeDef = TypedDict(
+    "GetNetworkTelemetryResponseTypeDef",
+    {
+        "NetworkTelemetry": List["NetworkTelemetryTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetRouteAnalysisRequestRequestTypeDef = TypedDict(
+    "GetRouteAnalysisRequestRequestTypeDef",
+    {
+        "GlobalNetworkId": str,
+        "RouteAnalysisId": str,
+    },
+)
+
+GetRouteAnalysisResponseTypeDef = TypedDict(
+    "GetRouteAnalysisResponseTypeDef",
+    {
+        "RouteAnalysis": "RouteAnalysisTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredGetSitesRequestRequestTypeDef = TypedDict(
     "_RequiredGetSitesRequestRequestTypeDef",
     {
@@ -921,6 +1173,82 @@ LocationTypeDef = TypedDict(
     total=False,
 )
 
+NetworkResourceCountTypeDef = TypedDict(
+    "NetworkResourceCountTypeDef",
+    {
+        "ResourceType": str,
+        "Count": int,
+    },
+    total=False,
+)
+
+NetworkResourceSummaryTypeDef = TypedDict(
+    "NetworkResourceSummaryTypeDef",
+    {
+        "RegisteredGatewayArn": str,
+        "ResourceArn": str,
+        "ResourceType": str,
+        "Definition": str,
+        "NameTag": str,
+        "IsMiddlebox": bool,
+    },
+    total=False,
+)
+
+NetworkResourceTypeDef = TypedDict(
+    "NetworkResourceTypeDef",
+    {
+        "RegisteredGatewayArn": str,
+        "AwsRegion": str,
+        "AccountId": str,
+        "ResourceType": str,
+        "ResourceId": str,
+        "ResourceArn": str,
+        "Definition": str,
+        "DefinitionTimestamp": datetime,
+        "Tags": List["TagTypeDef"],
+        "Metadata": Dict[str, str],
+    },
+    total=False,
+)
+
+NetworkRouteDestinationTypeDef = TypedDict(
+    "NetworkRouteDestinationTypeDef",
+    {
+        "TransitGatewayAttachmentId": str,
+        "ResourceType": str,
+        "ResourceId": str,
+    },
+    total=False,
+)
+
+NetworkRouteTypeDef = TypedDict(
+    "NetworkRouteTypeDef",
+    {
+        "DestinationCidrBlock": str,
+        "Destinations": List["NetworkRouteDestinationTypeDef"],
+        "PrefixListId": str,
+        "State": RouteStateType,
+        "Type": RouteTypeType,
+    },
+    total=False,
+)
+
+NetworkTelemetryTypeDef = TypedDict(
+    "NetworkTelemetryTypeDef",
+    {
+        "RegisteredGatewayArn": str,
+        "AwsRegion": str,
+        "AccountId": str,
+        "ResourceType": str,
+        "ResourceId": str,
+        "ResourceArn": str,
+        "Address": str,
+        "Health": "ConnectionHealthTypeDef",
+    },
+    total=False,
+)
+
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
@@ -931,6 +1259,16 @@ PaginatorConfigTypeDef = TypedDict(
     total=False,
 )
 
+PathComponentTypeDef = TypedDict(
+    "PathComponentTypeDef",
+    {
+        "Sequence": int,
+        "Resource": "NetworkResourceSummaryTypeDef",
+        "DestinationCidrBlock": str,
+    },
+    total=False,
+)
+
 RegisterTransitGatewayRequestRequestTypeDef = TypedDict(
     "RegisterTransitGatewayRequestRequestTypeDef",
     {
@@ -947,17 +1285,90 @@ RegisterTransitGatewayResponseTypeDef = TypedDict(
     },
 )
 
+RelationshipTypeDef = TypedDict(
+    "RelationshipTypeDef",
+    {
+        "From": str,
+        "To": str,
+    },
+    total=False,
+)
+
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
     {
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
 
+RouteAnalysisCompletionTypeDef = TypedDict(
+    "RouteAnalysisCompletionTypeDef",
+    {
+        "ResultCode": RouteAnalysisCompletionResultCodeType,
+        "ReasonCode": RouteAnalysisCompletionReasonCodeType,
+        "ReasonContext": Dict[str, str],
+    },
+    total=False,
+)
+
+RouteAnalysisEndpointOptionsSpecificationTypeDef = TypedDict(
+    "RouteAnalysisEndpointOptionsSpecificationTypeDef",
+    {
+        "TransitGatewayAttachmentArn": str,
+        "IpAddress": str,
+    },
+    total=False,
+)
+
+RouteAnalysisEndpointOptionsTypeDef = TypedDict(
+    "RouteAnalysisEndpointOptionsTypeDef",
+    {
+        "TransitGatewayAttachmentArn": str,
+        "TransitGatewayArn": str,
+        "IpAddress": str,
+    },
+    total=False,
+)
+
+RouteAnalysisPathTypeDef = TypedDict(
+    "RouteAnalysisPathTypeDef",
+    {
+        "CompletionStatus": "RouteAnalysisCompletionTypeDef",
+        "Path": List["PathComponentTypeDef"],
+    },
+    total=False,
+)
+
+RouteAnalysisTypeDef = TypedDict(
+    "RouteAnalysisTypeDef",
+    {
+        "GlobalNetworkId": str,
+        "OwnerAccountId": str,
+        "RouteAnalysisId": str,
+        "StartTimestamp": datetime,
+        "Status": RouteAnalysisStatusType,
+        "Source": "RouteAnalysisEndpointOptionsTypeDef",
+        "Destination": "RouteAnalysisEndpointOptionsTypeDef",
+        "IncludeReturnPath": bool,
+        "UseMiddleboxes": bool,
+        "ForwardPath": "RouteAnalysisPathTypeDef",
+        "ReturnPath": "RouteAnalysisPathTypeDef",
+    },
+    total=False,
+)
+
+RouteTableIdentifierTypeDef = TypedDict(
+    "RouteTableIdentifierTypeDef",
+    {
+        "TransitGatewayRouteTableArn": str,
+    },
+    total=False,
+)
+
 SiteTypeDef = TypedDict(
     "SiteTypeDef",
     {
@@ -973,6 +1384,39 @@ SiteTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredStartRouteAnalysisRequestRequestTypeDef = TypedDict(
+    "_RequiredStartRouteAnalysisRequestRequestTypeDef",
+    {
+        "GlobalNetworkId": str,
+        "Source": "RouteAnalysisEndpointOptionsSpecificationTypeDef",
+        "Destination": "RouteAnalysisEndpointOptionsSpecificationTypeDef",
+    },
+)
+_OptionalStartRouteAnalysisRequestRequestTypeDef = TypedDict(
+    "_OptionalStartRouteAnalysisRequestRequestTypeDef",
+    {
+        "IncludeReturnPath": bool,
+        "UseMiddleboxes": bool,
+    },
+    total=False,
+)
+
+
+class StartRouteAnalysisRequestRequestTypeDef(
+    _RequiredStartRouteAnalysisRequestRequestTypeDef,
+    _OptionalStartRouteAnalysisRequestRequestTypeDef,
+):
+    pass
+
+
+StartRouteAnalysisResponseTypeDef = TypedDict(
+    "StartRouteAnalysisResponseTypeDef",
+    {
+        "RouteAnalysis": "RouteAnalysisTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
@@ -1161,6 +1605,24 @@ UpdateLinkResponseTypeDef = TypedDict(
     },
 )
 
+UpdateNetworkResourceMetadataRequestRequestTypeDef = TypedDict(
+    "UpdateNetworkResourceMetadataRequestRequestTypeDef",
+    {
+        "GlobalNetworkId": str,
+        "ResourceArn": str,
+        "Metadata": Mapping[str, str],
+    },
+)
+
+UpdateNetworkResourceMetadataResponseTypeDef = TypedDict(
+    "UpdateNetworkResourceMetadataResponseTypeDef",
+    {
+        "ResourceArn": str,
+        "Metadata": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredUpdateSiteRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateSiteRequestRequestTypeDef",
     {
